==> touhoulittlemaid-fabric-1.21.1-0.1.0-neo1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/chatbubble/implement/ImageChatBubbleRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.implement;

import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.EntityMaidRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.EntityGraphics;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.IChatBubbleRenderer;
import net.minecraft.class_2960;

public class ImageChatBubbleRenderer implements IChatBubbleRenderer {
    private final int width;
    private final int height;
    private final int uOffset;
    private final int vOffset;
    private final int textureWidth;
    private final int textureHeight;
    private final class_2960 bg;
    private final class_2960 image;

    public ImageChatBubbleRenderer(int width, int height, int uOffset, int vOffset, int textureWidth,
                                   int textureHeight, class_2960 bg, class_2960 image) {
        this.width = width;
        this.height = height;
        this.uOffset = uOffset;
        this.vOffset = vOffset;
        this.textureWidth = textureWidth;
        this.textureHeight = textureHeight;
        this.bg = bg;
        this.image = image;
    }

    @Override
    public int getHeight() {
        return this.height;
    }

    @Override
    public int getWidth() {
        return this.width;
    }

    @Override
    public void render(EntityMaidRenderer renderer, EntityGraphics graphics) {
        graphics.blit(this.image, 0, 0, this.uOffset, this.vOffset, this.width, this.height, this.textureWidth, this.textureHeight);
    }

    @Override
    public class_2960 getBackgroundTexture() {
        return this.bg;
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.2.0-neo1.4.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/client/renderer/entity/chatbubble/implement/ImageChatBubbleRenderer.java <==
package com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.implement;

import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.EntityMaidRenderer;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.EntityGraphics;
import com.github.tartaricacid.touhoulittlemaid.client.renderer.entity.chatbubble.IChatBubbleRenderer;
import com.mojang.blaze3d.systems.RenderSystem;
import net.minecraft.class_2960;

public class ImageChatBubbleRenderer implements IChatBubbleRenderer {
    private final int width;
    private final int height;
    private final int uOffset;
    private final int vOffset;
    private final int textureWidth;
    private final int textureHeight;
    private final class_2960 bg;
    private final class_2960 image;

    public ImageChatBubbleRenderer(int width, int height, int uOffset, int vOffset, int textureWidth,
                                   int textureHeight, class_2960 bg, class_2960 image) {
        this.width = width;
        this.height = height;
        this.uOffset = uOffset;
        this.vOffset = vOffset;
        this.textureWidth = textureWidth;
        this.textureHeight = textureHeight;
        this.bg = bg;
        this.image = image;
    }

    @Override
    public int getHeight() {
        return this.height;
    }

    @Override
    public int getWidth() {
        return this.width;
    }

    @Override
    public void render(EntityMaidRenderer renderer, EntityGraphics graphics) {
        RenderSystem.enableBlend();
        RenderSystem.defaultBlendFunc();
        graphics.blit(this.image, 0, 0, this.uOffset, this.vOffset, this.width, this.height, this.textureWidth, this.textureHeight);
    }

    @Override
    public class_2960 getBackgroundTexture() {
        return this.bg;
    }
}
